← Dashboard

## 🎏 ShinkaEvolve: Program Evolution 🎏

Tree
PromptEvo
Programs
Metrics
Embed
Clusters
Islands
Ensembling
Path
MAPs
Transpose Tree (Left→Right) Animate Tree
Show incorrect programs

R | G | A | Patch Name | Type | I | Score | Cost | Complex. | Nov. | Res. | Patch | Model
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

#### Embedding Similarity Matrix

Sort by:
Color Scale:
Cell Size: 8px
Min Value: Max Value:
Y-Axis Range:
Min:
Max:
X-Axis:
Y-Axis:
Bins: 10
Fitness Min:
Fitness Max:
Gen: All

#### Model Posteriors Over Generations

##### Summary Statistics

#### PCA Embeddings

#### Metrics Over Generations

No meta-prompt database found

##### Patches

##### Avg. Improvement

Min Max
Best
Prompt Details

Select a prompt node to view details

##### Nodes

Best
Error

##### Patches

##### Performance

Min Max
▶

##### Islands

Meta
Pareto
Scratchpad
Node
Code
Diff
Evaluation
LLM
Analysis
Throughput

Select a node from the tree to view agent information.

Y-Axis:
X-Axis:
Generation: 5
Individual Programs
Global Insights
Meta Recommendations

Select a database to view meta analysis.

Select a node to view its details.

Select a node from the tree to view code.

Compare to:

Select a node to view its code diff.

Select a node to view its logs.

Select a node to view the LLM result.

### Program Correctness Rate

### Program Improvement Rate [P vs. C]

### Lines of Code across Generations

### Mutation Size vs Improvement

### Novelty Success Rates

#### Success Rate

#### Success vs Failures

### Resample Success Rates

#### Success Rate

#### Success vs Failures

### Patch Success Rate

#### Success Rate

#### Success vs Failures

### Patch Improvement Rate

#### Improvement Rate

### Cost by Model vs Patch Type

### Average Cost Across Generations

### Parent Lineage: Offspring Count & Improvements

### Throughput Summary

### Generation Runtime Timeline

### Worker Occupancy Over Time

### Normalized Worker Occupancy Over Time

### Evaluation Occupancy Distribution

### Completed Evaluations per Minute

### Stage Duration Summary

### Resource Utilization Summary